==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebDockManagerDescriptionModule.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, markType } from "./type";
import { WebSplitPaneDescriptionModule } from "./WebSplitPaneDescriptionModule";
import { WebContentPaneDescriptionModule } from "./WebContentPaneDescriptionModule";
import { WebDocumentHostDescriptionModule } from "./WebDocumentHostDescriptionModule";
import { WebTabGroupPaneDescriptionModule } from "./WebTabGroupPaneDescriptionModule";
import { WebTabHeaderElementDescriptionModule } from "./WebTabHeaderElementDescriptionModule";
import { WebDockManagerDescriptionMetadata } from "./WebDockManagerDescriptionMetadata";
/**
 * @hidden
 */
var WebDockManagerDescriptionModule = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebDockManagerDescriptionModule, _super);
    function WebDockManagerDescriptionModule() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDockManagerDescriptionModule.register = function (a) {
        WebSplitPaneDescriptionModule.register(a);
        WebContentPaneDescriptionModule.register(a);
        WebDocumentHostDescriptionModule.register(a);
        WebTabGroupPaneDescriptionModule.register(a);
        WebTabHeaderElementDescriptionModule.register(a);
        WebDockManagerDescriptionMetadata.d(a);
    };
    WebDockManagerDescriptionModule.$t = markType(WebDockManagerDescriptionModule, 'WebDockManagerDescriptionModule');
    return WebDockManagerDescriptionModule;
}(Base));
export { WebDockManagerDescriptionModule };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebDockManagerDescriptionModule.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "./type";
import { WebDockManagerLayoutDescriptionModule } from "./WebDockManagerLayoutDescriptionModule";
import { WebContentPaneDescriptionModule } from "./WebContentPaneDescriptionModule";
import { WebSplitPaneDescriptionModule } from "./WebSplitPaneDescriptionModule";
import { WebDocumentHostDescriptionModule } from "./WebDocumentHostDescriptionModule";
import { WebTabGroupPaneDescriptionModule } from "./WebTabGroupPaneDescriptionModule";
import { WebTabHeaderElementDescriptionModule } from "./WebTabHeaderElementDescriptionModule";
import { WebDockManagerDescriptionMetadata } from "./WebDockManagerDescriptionMetadata";
/**
 * @hidden
 */
var WebDockManagerDescriptionModule = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebDockManagerDescriptionModule, _super);
    function WebDockManagerDescriptionModule() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDockManagerDescriptionModule.register = function (a) {
        WebDockManagerLayoutDescriptionModule.register(a);
        WebContentPaneDescriptionModule.register(a);
        WebSplitPaneDescriptionModule.register(a);
        WebDocumentHostDescriptionModule.register(a);
        WebTabGroupPaneDescriptionModule.register(a);
        WebTabHeaderElementDescriptionModule.register(a);
        WebDockManagerDescriptionMetadata.d(a);
    };
    WebDockManagerDescriptionModule.$t = markType(WebDockManagerDescriptionModule, 'WebDockManagerDescriptionModule');
    return WebDockManagerDescriptionModule;
}(Base));
export { WebDockManagerDescriptionModule };
